@@ -1,8 +1,7 @@
-
 from django.apps import AppConfig
 
 
 class RestFrameworkTestConfig(AppConfig):
-    name = 'tests.rest_framework'
-    label = 'drf_test_app'
+    name = "tests.rest_framework"
+    label = "drf_test_app"
     verbose_name = "Rest Framework Test App"
