@@ -12,6 +12,7 @@ from django.utils import timezone
 from django_filters.fields import (
     BaseCSVField,
     BaseRangeField,
+    ChoiceField,
     DateRangeField,
     DateTimeRangeField,
     IsoDateTimeField,
@@ -58,6 +59,14 @@ class RangeFieldTests(TestCase):
         self.assertIsNone(f.clean([]))
 
 
+class ChoiceFieldTests(TestCase):
+    def test_callable_choices_is_lazy(self):
+        def choices():
+            self.fail("choices should not be called during initialization")
+
+        ChoiceField(choices=choices)
+
+
 class DateRangeFieldTests(TestCase):
     def test_field(self):
         f = DateRangeField()
